@@ -41,9 +41,21 @@ function machine_add_to_monitoring($con, $conf, $machine, $ignore_dot_ini_activa
                     exec($cmd, $output, $return_var);
                     $json["data"]["command"] = $cmd;
                     $json["data"]["output"] = $output;
+                } else {
+                    $json["status"] = "error";
+                    $json["message"] = "$script_path not found or wrong permissions.";
                 }
+            } else {
+                $json["status"] = "error";
+                $json["message"] = "No switch found.";
             }
+        } else {
+            $json["status"] = "error";
+            $json["message"] = "IP not found.";
         }
+    } else {
+        $json["status"] = "error";
+        $json["message"] = "Monitoring plugin not configured.";
     }
     return $json;
 }
@@ -60,8 +72,11 @@ function machine_delete_from_monitoring($con, $conf, $machine){
         exec($cmd, $output, $return_var);
         $json["data"]["command"] = $cmd;
         $json["data"]["output"] = $output;
+    } else {
+        $json["status"] = "error";
+        $json["message"] = "$script_path not found or wrong permissions.";
     }
     return $json;
 }
 
-?>
\ No newline at end of file
+?>
